==> haskell-wai-websockets-3.0.1.2-598-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-9nHJoyRnq606fUMLKLvv03
key:                  wai-websockets-3.0.1.2-9nHJoyRnq606fUMLKLvv03
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  11ad0e625232cf27fb5d30a34339ed1d
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-9nHJoyRnq606fUMLKLvv03
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI
    http-types-0.12.4-E9He9FXy4rKITKDtg1mhVt
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ transformers-0.6.1.0
    wai-3.2.4-DggAE0S6Fb43aX3BIvUJ63
    websockets-0.12.7.3-IxRNJzBRjoIAVwGwpWypj

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-websockets-3.0.1.2-599-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-websockets.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-websockets
version:              3.0.1.2
visibility:           public
id:                   wai-websockets-3.0.1.2-DcsKMh1jM6XBbyEBtt9HnZ
key:                  wai-websockets-3.0.1.2-DcsKMh1jM6XBbyEBtt9HnZ
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Jasper Van der Jeugt, Ting-Yen Lai
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provide a bridge between WAI and the websockets package.
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-websockets>.

category:             Web, Yesod
abi:                  d32febf61cd0d7b306dc44f40ab5c6f8
exposed:              True
exposed-modules:      Network.Wai.Handler.WebSockets
import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-websockets-3.0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-websockets
hs-libraries:         HSwai-websockets-3.0.1.2-DcsKMh1jM6XBbyEBtt9HnZ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-8PStX6cixKCLkUJoPuARL
    http-types-0.12.4-2YF0olXF9itCctWavExzmH
    network-3.1.4.0-xB4epdb1XO3ZKzAxljM4X transformers-0.6.1.0
    wai-3.2.4-BLc210LwMQhDvJHRqgIjev
    websockets-0.12.7.3-2spokc2S1282Q6F8NCy0hy

haddock-interfaces:
    /usr/share/doc/haskell-wai-websockets/html/wai-websockets.haddock

haddock-html:         /usr/share/doc/haskell-wai-websockets/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
